@@ -42,9 +42,10 @@ build_time_vars = {'ABIFLAGS': '',
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
-                "'--with-threads' '--without-ensurepip' '--without-pymalloc' "
+                "'--without-ensurepip' '--without-pymalloc' "
                 "'--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' "
                 "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
+                "'--enable-option-checking=yes' "
                 "'build_alias=armv6--netbsdelf-eabihf' "
                 "'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 "
                 "-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include' "
@@ -56,8 +57,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3/lcov-report',
+ 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -683,7 +684,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -711,7 +712,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -725,10 +726,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -749,8 +750,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
- 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
+ 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4',
+ 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.4',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
